@@ -1,9 +1,6 @@
 from nose.plugins.skip import SkipTest
 from urllib3.packages import six
 
-if six.PY3:
-    raise SkipTest('Testing of PyOpenSSL disabled on PY3')
-
 try:
     from urllib3.contrib.pyopenssl import (inject_into_urllib3,
                                            extract_from_urllib3)
